# Servicio de Simulación de Documentos Digitalizados

Este documento explica cómo utilizar el servicio de simulación de documentos digitalizados para fines educativos. El servicio genera información ficticia de personas basada en números de documentos de identidad (cédulas).

## Características principales

- Generación de datos personales ficticios deterministas (siempre los mismos para la misma cédula)
- Simulación de errores y advertencias controladas mediante patrones en los números de cédula
- Generación de edades específicas basadas en los últimos dígitos de la cédula

## Cómo generar errores y advertencias específicos

El servicio utiliza los **dos primeros dígitos** de la cédula para determinar si ocurre un error o una advertencia:

| Dos primeros dígitos | Resultado generado                           |
| -------------------- | -------------------------------------------- |
| 11                   | Error - Persona inexistente                  |
| 12                   | Error - Límite de consultas excedido         |
| 13                   | Error - Número de cédula anulado             |
| 14                   | Advertencia - Datos de persona a regularizar |
| 15                   | Advertencia - Documento hurtado o extraviado |
| Otros                | Sin errores ni advertencias                  |

Por ejemplo, si consulta la cédula `11.234.567-8`, el servicio devolverá un error indicando que la persona no existe.

## Cómo obtener cédulas con edades específicas

La edad de la persona generada se determina por los **últimos dos dígitos** de la cédula:

- Para una persona de 25 años: use una cédula que termine en "25"
- Para una persona de 18 años: use una cédula que termine en "18"
- Para una persona de 65 años: use una cédula que termine en "65"

Por ejemplo, la cédula `4.321.025-9` generará una persona que tiene 25 años.

## Ejemplos de uso

### Ejemplos de cédulas que generan errores:

- `11.234.567-8`: Error - Persona inexistente
- `12.345.678-9`: Error - Límite de consultas excedido
- `13.456.789-0`: Error - Número de cédula anulado

### Ejemplos de cédulas que generan advertencias:

- `14.567.890-1`: Sin error, con advertencia - Datos a regularizar
- `15.456.789-0`: Sin error, con advertencia - Documento hurtado/extraviado
- `56.789.123-4`: Sin error, sin advertencia (no comienza con 11-15)

### Ejemplos de cédulas con edades específicas:

- `4.321.018-9`: Persona de 18 años
- `5.678.930-3`: Persona de 30 años
- `6.789.045-1`: Persona de 45 años
- `7.890.175-8`: Persona de 75 años

### Combinando características:

- `15.467.825-7`: Persona de 25 años con advertencia de documento hurtado
- `14.418.965-3`: Persona de 65 años con advertencia de datos a regularizar

## Otros datos generados

Además de la edad, el servicio genera determinísticamente para cada cédula:

- Nombres y apellidos
- Sexo (basado en el número de cédula)
- Fecha de nacimiento (basada en la edad)
- Nacionalidad
- Nombres completos para la cédula
- Identificadores de solicitud y respuesta

## Notas importantes

1. Los datos generados son ficticios y no corresponden a personas reales.
2. El servicio es determinista: la misma cédula siempre generará los mismos datos.
3. Para edades de 0-9, asegúrese de incluir un cero delante (por ejemplo, "05" para 5 años).
4. Para cédulas sin dígitos suficientes, el sistema puede comportarse de manera inesperada.

## Formato de parámetros requeridos

Para realizar una consulta válida, debe proporcionar los siguientes parámetros:

- `NroDocumento`: Número de cédula (requerido)
- `NroSerie`: Número de serie del documento (requerido)
- `Organismo`: Código del organismo solicitante (requerido)
- `ClaveAcceso1`: Clave de acceso (requerida)
- `TipoDocumento`: Tipo de documento (opcional)

La ausencia de cualquiera de los parámetros requeridos resultará en un error de "Parámetros incorrectos".
